import { Component } from "@angular/core";
import { ActivatedRoute, Router } from "@angular/router";
import { BlockUI, NgBlockUI } from "ng-block-ui";
import { ChartApiService } from "src/app/_services/chart.api";
interface Sales {
  name: string;
  sales: string;
  receipts: string;
  due: string;
}

@Component({
  selector: "app-detail",
  templateUrl: "./detail.component.html",
  styleUrls: ["./detail.component.css"],
})
export class DetailComponent {
  data: any;
  chartOption: any;
  Sales: any;
  salesData: any;
  lineArea: any;
  mode: string;
  ExpenseschartOption: any;
  donutChart2: any;
  public breadcrumb: any;
  constructor(
    private chartApiservice: ChartApiService,
    private router: Router,
    private route: ActivatedRoute
  ) {}
  hitRateOptions = {
    bodyClass: ['bg-hexagons', 'pt-0'],
    headerClass: ['bg-hexagons'],
    cardClass: ['pull-up'],
    close: false,
    expand: false,
    minimize: false,
    reload: true
  };
  @BlockUI("totalReceivables") blockUITotalReceivables: NgBlockUI;
  @BlockUI("salesRecieptsDues") blockUISalesRecieptsDues: NgBlockUI;
  carouselOne = [
    '../../../assets/images/carousel/02.jpg',
    '../../../assets/images/carousel/03.jpg',
    '../../../assets/images/carousel/01.jpg'
  ];

  ngOnInit() {
    this.route.data.subscribe((data) => {
      this.mode = data.mode;
    });
    if (this.mode === "room") {
      this.breadcrumb = {
        mainlabel: "Detail Monitoring",
        linkBack: "/monitoring/monitoring-room",
        isLinkBack: true,
        links: [
          {
            name: "Home",
            isLink: false,
            link: "",
          },
          {
            name: "Detail Monitoring",
            isLink: false,
            link: "",
          },
        ],
      };
    } else {
      this.breadcrumb = {
        mainlabel: "Detail Monitoring",
        linkBack: "/monitoring",
        isLinkBack: true,
        links: [
          {
            name: "Home",
            isLink: false,
            link: "",
          },
          {
            name: "Detail Monitoring",
            isLink: false,
            link: "",
          },
        ],
      };
    }

    this.chartApiservice.getStatisticsData().subscribe(Response => {
      this.salesData = Response;
      this.getlineArea();
      });

    this.chartApiservice.getInvoiceData().subscribe((Response) => {
      this.data = Response;
      this.getInvoicechart();
    });
  }

  getlineArea(){
    const ChartData = this.salesData;

    // this.lineArea = {
    //   type: 'Line',
    //   data: ChartData['lineArea'],
    //   options: {
    //     // low: 650,
    //     fullwidth: true,
    //     height: '80px',
    //     showArea: true,
    //     axisX: {
    //       showGrid: false,
    //       showLabel: false
    //     },
    //     axisY: {
    //       showGrid: false,
    //       showLabel: false
    //     }
    //   }
    // };

    this.lineArea = {
      type: 'Line',
      data: ChartData['lineArea'],
      options: {
        // low: 650,
        fullwidth: true,
        height: '75px',
        showArea: true,
        axisX: {
          showGrid: false,
          showLabel: false
        },
        axisY: {
          showGrid: false,
          showLabel: false
        }
      }
    };
  }

  getInvoicechart() {
    this.Sales = this.data["sales"];
    this.chartOption = {
      grid: {
        x: 40,
        x2: 40,
        y: 35,
        y2: 25,
      },

      // Add tooltip
      tooltip: {
        trigger: "axis",
        enterable: false,
      },

      // Add legend
      legend: {
        data: ["Total Sales", "Total Receipts", "Total Expenses"],
      },

      // Add custom colors
      color: ["#3BAFDA", "#37BC9B", "#F6BB42"],

      // Horizontal axis
      xAxis: [
        {
          type: "category",
          data: [
            "Jan",
            "Feb",
            "Mar",
            "Apr",
            "May",
            "Jun",
            "Jul",
            "Aug",
            "Sep",
            "Oct",
            "Nov",
            "Dec",
          ],
        },
      ],

      // Vertical axis
      yAxis: [
        {
          type: "value",
        },
      ],

      // Add series
      series: [
        {
          name: "Total Sales",
          type: "bar",
          data: this.data.TotalSales.TotalSales[0],
        },
        {
          name: "Total Receipts",
          type: "bar",
          data: this.data.TotalReceipts.TotalReceipts[0],
        },
        {
          name: "Total Expenses",
          type: "bar",
          data: this.data.TotalExpenses.TotalExpenses[0],
        },
      ],
    };
    this.ExpenseschartOption = {
      legend: {
        orient: "horizontal",
        x: "center",
        data: ["Internet", "Infrastructure", "Party", "Assets", "Electricity"],
      },

      // Add custom colors
      color: ["#FECEA8", "#FF847C", "#E84A5F", "#2A363B", "#99B898"],

      // Display toolbox
      toolbox: {
        show: true,
        orient: "vertical",
      },

      series: [
        {
          name: "Browsers",
          type: "pie",
          radius: ["50%", "70%"],
          center: ["50%", "57.5%"],
          itemStyle: {
            normal: {
              label: {
                show: true,
              },
              labelLine: {
                show: true,
              },
            },
            emphasis: {
              label: {
                show: true,
                formatter: "{b}" + "\n\n" + "{c} ({d}%)",
                position: "center",
                textStyle: {
                  fontSize: "17",
                  fontWeight: "500",
                },
              },
            },
          },
          data: [
            { value: 335, name: "Internet" },
            { value: 1548, name: "Infrastructure" },
            { value: 135, name: "Party" },
            { value: 234, name: "Assets" },
            { value: 650, name: "Electricity" },
          ],
        },
      ],
    };
  }

  reloadTotalReceivables() {
    this.blockUITotalReceivables.start("Loading..");

    setTimeout(() => {
      this.blockUITotalReceivables.stop();
    }, 2500);
  }

  reloadSalesRecieptsDues() {
    this.blockUISalesRecieptsDues.start("Loading..");

    setTimeout(() => {
      this.blockUISalesRecieptsDues.stop();
    }, 2500);
  }
}
